# Security Policy

## Supported Versions

| Version | Supported          |
|---------|--------------------|
| 0.1.x   | :white_check_mark: |

## Reporting a Vulnerability

If you discover a security vulnerability, please report it via [GitHub Security Advisories](https://github.com/HikaruEgashira/otel-hooks/security/advisories/new).

Do **not** open a public issue for security vulnerabilities.

You can expect an initial response within 72 hours. We will work with you to understand the issue and coordinate a fix before any public disclosure.
